@@ -2,7 +2,7 @@
 /*
  * This file is part of Codecrypt.
  *
- * Copyright (C) 2013-2016 Mirek Kratochvil <exa.exa@gmail.com>
+ * Copyright (C) 2013-2017 Mirek Kratochvil <exa.exa@gmail.com>
  *
  * Codecrypt is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
@@ -40,7 +40,7 @@ public:
 		r.clear();
 	}
 
-	void seed (uint bits, bool quick = true);
+	bool seed (uint bits, bool quick = true);
 
 	uint random (uint n) {
 		randmax_type i;
